--
-- This demo includes:
-- * stubs for the DragXxxx events generated by the DragBar class
-- * stubs for the HUDxxxx events generated by the DragBar class
-- * shows how a control can guarantee it's hidden when the HUD is invisible by using the DragBar:HideTargetIfHUDHidden method
-- * shows how a control can track what visible state it wants to be in and ensure it is properly revealed/hidden when the HUD is shown
-- * shows how a control can tell the DragBar to recalculate its size and position using DragBar:Refresh()
--

import "Turbine.UI";
import "Turbine.UI.Lotro";
import "Deusdictum.UI";

DBDemoWindowTwo = class( Turbine.UI.Window );

function DBDemoWindowTwo:Constructor( )
	Turbine.UI.Window.Constructor( self );

	self:SetSize( 250, 250 );
	self:SetPosition( ( Turbine.UI.Display:GetWidth() - 250 ) / 3, ( Turbine.UI.Display:GetHeight() - 250 ) / 3 );
	math.randomseed( Turbine.Engine.GetLocalTime() );
	self:SetBackColor( Turbine.UI.Color( math.random(), math.random(), math.random() ) );
	self:SetText( "Demo Window" );
	self.DragBar = Deusdictum.UI.DragBar( self, "DragBar Demo Window" );
	self.DragBar:SetBarOnTop( true );

	self.DragEnable = function( )
		Turbine.Shell.WriteLine( "DragEnable received." );
	end

	self.DragDisable = function( )
		Turbine.Shell.WriteLine( "DragDisable received." );
	end

	self.DragStart = function( )
		Turbine.Shell.WriteLine( "DragStart received." );
	end

	self.DragEnd = function( )
		Turbine.Shell.WriteLine( "DragEnd received." );
	end

	self.HUDShow = function( )
		Turbine.Shell.WriteLine( "HUDShow received." );
		self:SetVisible( self.bWantsToBeVisible );
	end

	self.HUDHide = function( )
		Turbine.Shell.WriteLine( "HUDHide received." );
	end

	self.VisibleChanged = function( sender, args )
		self.DragBar:HideTargetIfHUDHidden();

		if self:IsVisible() then
			Turbine.Shell.WriteLine( "Visible event received." );
		else
			Turbine.Shell.WriteLine( "Hidden event received." );
		end
	end

	self.ToggleWindow = Turbine.UI.Window();
	self.ToggleWindow:SetSize( 200, 80 );
	self.ToggleWindow:SetPosition( self:GetLeft() - 200, self:GetTop() + ( self:GetHeight() - 80 ) / 2 );
	self.ToggleWindow:SetBackColor( Turbine.UI.Color( 1, 0, 0, 0 ) );
	self.ToggleWindow:SetVisible( true );
	self.ToggleWindow:SetOpacity( 1 );

	self.Toggle1 = Turbine.UI.Lotro.GoldButton();
	self.Toggle1:SetParent( self.ToggleWindow );
	self.Toggle1:SetSize( 160, 40 );
	self.Toggle1:SetPosition( 20, ( 40 - self.Toggle1:GetHeight() ) / 2 );
	self.Toggle1:SetText( "Hide Demo Window" );
	self.Toggle1:SetVisible( true );

	self.Toggle1.Click = function( sender, args )
		self.bWantsToBeVisible = not self.bWantsToBeVisible;
		self:SetVisible( self.bWantsToBeVisible );

		if self.bWantsToBeVisible then
			self.Toggle1:SetText( "Hide Demo Window" );
		else
			self.Toggle1:SetText( "Show Demo Window" );
		end
	end

	self.Toggle2 = Turbine.UI.Lotro.GoldButton();
	self.Toggle2:SetParent( self.ToggleWindow );
	self.Toggle2:SetSize( 160, 40 );
	self.Toggle2:SetPosition( 20, ( 40 - self.Toggle2:GetHeight() ) / 2 + 40 );
	self.Toggle2:SetText( "Make Bigger" );
	self.Toggle2:SetVisible( true );

	self.Toggle2.Click = function( sender, args )
		self.bWantsToBeBig = not self.bWantsToBeBig;
		if self.bWantsToBeBig then
			self:SetSize( 350, 350 );
		else
			self:SetSize( 200, 200 );
		end
		self.DragBar:Refresh();

		if self.bWantsToBeBig then
			self.Toggle2:SetText( "Make Smaller" );
		else
			self.Toggle2:SetText( "Make Bigger" );
		end
	end

	self.bWantsToBeBig = false;
	self.bWantsToBeVisible = true;
	self:SetVisible( true );
	self:SetOpacity( math.random() * 3 / 4 + 0.25 );
end
